@@ -4,7 +4,7 @@
 modname = 'rqlcontroller'
 distname = 'cubicweb-rqlcontroller'
 
-numversion = (0, 6, 0)
+numversion = (0, 7, 1)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -23,5 +23,7 @@ classifiers = [
     'Environment :: Web Environment',
     'Framework :: CubicWeb',
     'Programming Language :: Python',
+    'Programming Language :: Python :: 3',
+    'Programming Language :: Python :: 3 :: Only',
     'Programming Language :: JavaScript',
 ]
