@@ -33,6 +33,7 @@ from cubicweb.web import RemoteCallFailed, DirectResponse
 from cubicweb.web.controller import Controller
 from cubicweb.web.views.urlrewrite import rgx_action, SchemaBasedRewriter
 from cubicweb import Binary
+from cubicweb_rqlcontroller.rql_schema_holder import RqlIOSchemaHolder
 
 
 ARGRE = re.compile(r'__r(?P<ref>\d+)$')
@@ -74,6 +75,18 @@ class match_request_content_type(ExpectedValuePredicate):
         return header
 
 
+class RqlIOSchemaController(Controller):
+    __regid__ = 'rqlio_schema'
+    __select__ = match_http_method('GET', 'HEAD')
+
+    def publish(self, rset=None):
+        self._cw.set_content_type('application/json')
+        self._cw.add_header('Etag', RqlIOSchemaHolder.get_schema_hash(self._cw))
+        return json.dumps(
+            RqlIOSchemaHolder.get_schema(self._cw)
+        ).encode(self._cw.encoding)
+
+
 class RqlIOController(Controller):
     """posted rql queries and arguments use the following pattern:
 
@@ -167,6 +180,8 @@ class RqlIOController(Controller):
 
 class RQLIORewriter(SchemaBasedRewriter):
     rules = [
+        (re.compile('/rqlio/schema'),
+         rgx_action(controller='rqlio_schema')),
         (re.compile('/rqlio/(?P<version>.+)$'),
-         rgx_action(controller='rqlio', formgroups=('version',))),
+         rgx_action(controller='rqlio', formgroups=('version',)))
     ]
